import { render } from "react-dom";
import "./index.css";
import * as React from "react";
import {
  DiagramComponent,
  DiagramContextMenu,
  MoveTool,
  SelectorConstraints,
  Diagram,
  PortVisibility,
  PortConstraints,
  randomId,
  cloneObject,
  ConnectorDrawingTool
} from "@syncfusion/ej2-react-diagrams";
import { SampleBase } from "./sample-base";
import {
  DropDownButtonComponent,
  ItemModel
} from "@syncfusion/ej2-react-splitbuttons";

Diagram.Inject(DiagramContextMenu);

let port = [
  {
    id: "Port1",
    offset: { x: 0, y: 0.5 },
    visibility: PortVisibility.Connect | PortVisibility.Hover,
    constraints: PortConstraints.Draw
  },
  {
    id: "Port2",
    offset: { x: 0.5, y: 0 },
    visibility: PortVisibility.Connect | PortVisibility.Hover,
    constraints: PortConstraints.Draw
  },
  {
    id: "Port3",
    offset: { x: 1, y: 0.5 },
    visibility: PortVisibility.Connect | PortVisibility.Hover,
    constraints: PortConstraints.Draw
  },
  {
    id: "Port4",
    offset: { x: 0.5, y: 1 },
    visibility: PortVisibility.Connect | PortVisibility.Hover,
    constraints: PortConstraints.Draw
  }
];

let node1 = {
  id: "node",
  offsetX: 200,
  offsetY: 200,
  width: 160,
  height: 100,
  ports: port
};
let node2 = {
  id: "node2",
  offsetX: 400,
  offsetY: 200,
  width: 160,
  height: 100,
  ports: port
};
let node3 = {
  id: "node3",
  offsetX: 200,
  offsetY: 400,
  width: 160,
  height: 100,
  ports: port
};

let connectors = [
  {
    id: "connector",
    sourcePoint: { x: 250, y: 290 },
    targetPoint: { x: 400, y: 400 }
  }
];

let handles = [
  {
    name: "rightHandle",
    pathColor: "white",
    backgroundColor: "#7d7d7d",
    borderColor: "white",
    //set an image source
    source: "./edit.png",
    visible: true,
    offset: 0.5,
    side: "Right",
    horizontalAlignment: "Center",
    verticalAlignment: "Center"
  }
];

let diagramInstance;

export class HtmlNode extends SampleBase {
  rendereComplete() {}

  render() {
    return (
      <div className="control-pane">
        <div className="control-section">
          <DiagramComponent
            id="diagram"
            ref={diagram => (diagramInstance = diagram)}
            width={"100%"}
            height={"640px"}
            nodes={[node1, node2, node3]}
            connectors={connectors}
            getCustomTool={getTool}
            selectedItems={{
              constraints: SelectorConstraints.UserHandle,
              userHandles: handles
            }}
          ></DiagramComponent>
        </div>
      </div>
    );
  }
}

//Defines the connector drawing tool
class DrawingTool extends ConnectorDrawingTool {
  mouseDown(args) {
    super.mouseDown(args);
    //get the selectedNode
    this.sourceNode = diagramInstance.selectedItems.nodes[0];
    //set the drawing object connector
    diagramInstance.drawingObject = { type: "Orthogonal" };
  }

  mouseMove(args) {
    super.mouseMove(args);
  }

  mouseUp(args) {
    super.mouseUp(args);
    if (diagramInstance.selectedItems.connectors.length > 0) {
      //set connector sourceId
      diagramInstance.selectedItems.connectors[0].sourceID = this.sourceNode.id;
      //immediate reflection on DOM
      diagramInstance.dataBind();
      //clear the node selection
      diagramInstance.clearSelection();
      diagramInstance.drawingObject = null;
    }
  }
}

//Enable the clone Tool for UserHandle.
function getTool(action) {
  let tool;
  if (action === "rightHandle") {
    tool = new DrawingTool(diagramInstance.commandHandler);
  }
  return tool;
}
render(<HtmlNode />, document.getElementById("sample"));
